package oracle.forms.demos.javamail;
import java.io.*;
import java.net.InetAddress;
import java.util.Properties;
import java.util.Date;

import javax.mail.*;
import javax.mail.internet.*;
import javax.activation.*;

/** <H3><FONT COLOR="003399">Forms JavaMail Integration Sample</FONT></H3><br>
 *  This sample provides a simple wrapper function on top of the JavaMail API which can be called from PL/SQL
 *  via ORA_JAVA code generated by the Java Importer
 *
 * @author kprakash, drmills
 * @author 06-December-2001
 * @version 2.0
 */

public class SendMessage
{

/**
 * send is a static method that performs some basic validation and then sends the e-mail
 * @param <b>SMTPhost</b> name or ip address of the SMTP mail host
 * @param <b>From</b> Email address of sender
 * @param <b>To</b> Email address(es) of the recipient(s).  If multiple addresses are specified separate them with a space.
 * @param <b>Subject</b> Subject for the Email
 * @param <b>Body</b> Email text
 * @param <b>Attachment</b> File to attach - must be present on the Middle tier not the Browser client
 */
  public static void send(String SMTPhost,
                          String From,
                          String To,
                          String Subject,
                          String Body,
                          String Attachment) throws SendMessageException
  {
    int StartPos = 0;
    int EndPos;
    char LastAttachChar;
    String Filename;
    String operation = null;

    //Check if attachment is null
    if (Attachment == null||Attachment.equals(""))
    {
      EndPos=0;
    }
    else
    {
      EndPos=Attachment.length();
      LastAttachChar = Attachment.charAt(EndPos-1);

      //If Attachment is terminated by comma, delete the last character from attachment
      if (LastAttachChar==',')
      {
        Attachment = Attachment.substring(StartPos,EndPos-1);
        EndPos=Attachment.length();
      }
    }

    //Get properties and default session for the SMTP server
    Properties props = System.getProperties();
    props.put("mail.smtp.host", SMTPhost);
    Session session = Session.getDefaultInstance(props, null);

    //Now try and create the mail message
    try
    {
      //Create a message
      Message msg = new MimeMessage(session);

      //Add sender to message
      operation = "FROM";
      msg.setFrom(new InternetAddress(From));

      //Add reciepient list to message
      operation = "TO";
      InternetAddress[] address = InternetAddress.parse(To,false);
      msg.setRecipients(Message.RecipientType.TO, address);

      //Add subject to message
      msg.setSubject(Subject);

      //Add date to message
      msg.setSentDate(new Date());

      //Add a new part to the message
      Multipart mp = new MimeMultipart();
      {
        MimeBodyPart mbp = new MimeBodyPart();
        //Add the body to the new part
        mbp.setText(Body);
        mp.addBodyPart(mbp);
      }
      //Parse the attachment list and add files to the new part
      if (EndPos != 0)
      {
        //Get the first and last positions of the file separator
        int FilesepPos     = Attachment.indexOf(",");
        int FilesepLastPos = Attachment.lastIndexOf(",");

        //The attachment contains only one file
        if (FilesepPos==-1)
        {
          FilesepPos=EndPos;
          EndPos=0;
        }

        while (true)
        {
          MimeBodyPart mbp = new MimeBodyPart();
          Filename = Attachment.substring(StartPos,FilesepPos);
          FileDataSource fds = new FileDataSource(Filename);
          mbp.setDataHandler(new DataHandler(fds));
          mbp.setFileName(fds.getName());
          mp.addBodyPart(mbp);
          if (EndPos==0)
          {
            break;
          }
          Attachment = Attachment.substring(FilesepPos+1,EndPos);
          EndPos = Attachment.length();
          if (FilesepPos==FilesepLastPos)
          {
            FilesepPos=EndPos;
            EndPos=0;
          }
          else
          {
            FilesepPos    = Attachment.indexOf(",");
            FilesepLastPos = Attachment.lastIndexOf(",");
          }
        }
      }

      //Add the new part to the message
      msg.setContent(mp);

      //Send the message
      Transport.send(msg);
    }
    catch (AddressException aex)
    {
      throw new SendMessageException("Email Address error " + operation + " value > " + aex.getMessage());
    }
    catch (MessagingException mex)
    {
      //Ignore the top level exception as this just tells us the main was not sent
      //The next exception will give more detail
      Exception nested = mex.getNextException();
      throw new SendMessageException(nested.getMessage());
    }
    catch (Exception ex)
    {
      throw new SendMessageException(ex.toString());
    }
  }


/**
 * Use for testing. Substitute your values into the code.
 */


  public static void main(String[] args)
  {
    try
    {
      SendMessage sm = new SendMessage();
      sm.send("<your smtp server>","<from>","<to>","Test from Main","blaa blaa","");
    }
    catch(SendMessageException sme)
    {
      System.out.println(sme.getMessage());
    }
  }
}