package oracle.forms.jdapi.demo;

import oracle.forms.jdapi.demo.util.CommandLineArgs;
import oracle.forms.jdapi.demo.util.DemoArgumentsException;
import oracle.forms.jdapi.*;

/** Forms JAVA API (JDAPI): <b>Sample 7</b> - <em>ChangeColors</em><br>
 *  This sample provides a small utility which can be used to set the
 *  foreground or background colors of items or canvases en mass
 *
 * @author drmills
 * @author 16-January-2002
 * @version 1.0
 */
public class ChangeColors
{
  static String s_sample_name    = "ChangeColor";
  static String s_sample_version = "1.0";
  final static int ALL_TARGET = -1;
  final static int NO_TARGET = -2;
  
  public ChangeColors(String[] mainArgs)
  {
    //Print header
    System.out.println(s_sample_name + " Version " + s_sample_version);

    // use the utility class CommandLineArgs to find the name of the
    // form to process
    CommandLineArgs args = new CommandLineArgs(mainArgs);
    
    String formName;
    String targetType;
    String subType;
    int    targetId = NO_TARGET;    
    String bgColor                    = null;
    String fgColor                    = null;
    boolean isCanvas;
    JdapiIterator targetIterator      = null;
    JdapiIterator targetChildIterator = null;    
    Canvas canvas                     = null;
    Block  block                      = null;
    Item   item                       = null;
    String targetName                 = null;
    String blockName                  = null;


    try
    {
      //Process the command line arguments 
      formName = args.getValue("FORM",null);
      if (formName == null)
      {
        throw new DemoArgumentsException("Form name and location must be supplied");
      }

      targetType = args.getUppercaseValue("TARGET_TYPE",null);
      if ((targetType == null) || (!targetType.equals("CANVAS") && !targetType.equals("ITEM")))
      {
        throw new DemoArgumentsException("TARGET_TYPE of CANVAS or ITEM must be supplied");
      }
      else if (targetType.equals("CANVAS"))
           {
             isCanvas = true;
             subType = args.getUppercaseValue("CANVAS_TYPE","ALL");
             if (subType.equals("ALL"))
               targetId = ALL_TARGET;
             else if (subType.equals("CONTENT"))
                 targetId = JdapiTypes.CNTY_CONTENT_CTID;
             else if (subType.equals("STACKED"))
                 targetId = JdapiTypes.CNTY_STACKED_CTID;
             else if (subType.equals("TAB"))
                 targetId = JdapiTypes.CNTY_TAB_CTID;             
             else if (subType.equals("HTOOLBAR"))
                 targetId = JdapiTypes.CNTY_HTOOLBAR_CTID;             
             else if (subType.equals("VTOOLBAR"))
                 targetId = JdapiTypes.CNTY_VTOOLBAR_CTID;             
             else
             {
                throw new DemoArgumentsException("CANVAS_TYPE must be one of: ALL, CONTENT, STACKED, TAB, HTOOLBAR, VTOOLBAR");
             }
           }
           else
           {
             isCanvas = false;
             subType = args.getUppercaseValue("ITEM_TYPE","ALL");
             if (subType.equals("ALL"))
                targetId = ALL_TARGET;
             else if (subType.equals("TEXT"))
                 targetId = JdapiTypes.ITTY_TI_CTID;             
             else if (subType.equals("DISPLAY"))
                 targetId = JdapiTypes.ITTY_DI_CTID;            
             else if (subType.equals("CHECKBOX"))
                 targetId = JdapiTypes.ITTY_CB_CTID;
             else if (subType.equals("BUTTON"))
                 targetId = JdapiTypes.ITTY_PB_CTID;
             else if (subType.equals("LIST"))
                 targetId = JdapiTypes.ITTY_LS_CTID;
             else
             {
               throw new DemoArgumentsException("ITEM_TYPE must be one of: ALL, TEXT, DISPLAY, CHECKBOX, BUTTON, LIST");
             }
           }
           
      bgColor = args.getValue("BACKGROUND",null);
      fgColor = args.getValue("FOREGROUND",null);

      if ((bgColor == null) && (fgColor == null))
      {
         throw new DemoArgumentsException("At least one of FOREGROUND or BACKGROUND must be supplied");
      }


      // Open the Form - First setting the options to ensure that we can 
      // Find the attached libraries and Subclassing...
      Jdapi.setFailLibraryLoad(true);
      Jdapi.setFailSubclassLoad(true);

      FormModule formModule = FormModule.open(formName);

      System.out.println("Form " + formModule.getName() + " opened...");

      if (isCanvas)
      {
        targetIterator = formModule.getCanvases();
        while (targetIterator.hasNext())
        {
          canvas = (Canvas)targetIterator.next();
          if ((targetId == ALL_TARGET) || (canvas.getCanvasType()==targetId))
          {
            targetName = canvas.getName();
            if (bgColor != null)
            {
              System.out.println("Changing background of " + targetName + " from " + canvas.getBackColor() + " to " + bgColor);
              canvas.setBackColor(bgColor);
            }
            if (fgColor != null)
            {
              System.out.println("Changing foreground of " + targetName + " from " + canvas.getForegroundColor() + " to " + fgColor);
              canvas.setForegroundColor(fgColor);
            }
          }
        }
      }
      else
      {
        targetIterator = formModule.getBlocks();
        while (targetIterator.hasNext())
        {
          block = (Block)targetIterator.next();
          blockName = block.getName();
          targetChildIterator = block.getItems();
          while (targetChildIterator.hasNext())
          {
            item = (Item)targetChildIterator.next();
            targetName = blockName + '.' + item.getName();
            if ((targetId == ALL_TARGET) || (item.getItemType() == targetId))
            {
              if (bgColor != null)
              {
                System.out.println("Changing background of " + targetName + " from " + item.getBackColor() + " to " + bgColor);              
                item.setBackColor(bgColor);
              }
              if (fgColor != null)
              {
                System.out.println("Changing foreground of " + targetName + " from " + item.getForegroundColor() + " to " + fgColor);              
                item.setForegroundColor(fgColor);
              }            
            }
          }
        }
      }


      // Save the Form so we can look at it in the builder to prove this
      // all worked
      formModule.save(formName);
      System.out.println("Altered Form Saved...");
      // Clean Up
      Jdapi.shutdown();
    }
    catch (DemoArgumentsException daex)
    {
      printError(daex.toString());
      this.printUsage();
    }
    catch (JdapiException jex)
    {
      printError(jex.toString());
    }

    // Clean up
 //   Jdapi.shutdown();
  }



  /**
   * Simply prints an error message to the console
   * @param <b>errorString</b> the message to print
   * @return no return value
   * @exception no exceptions thrown
   */
  private static void printError(String errorString)
  {
    System.out.println(s_sample_name + " ERROR: " + errorString);
  }
  
  /**
   * Prints out the usage for this sample
   * @return no return value
   * @exception no exceptions thrown
   */
  public static void printUsage()
  {
    System.out.println("\n" + s_sample_name + ":\n-------------------\n"
                     + "This class allows you to change the color of items or "
                     + "canvases.\n"
                     + "Usage:\n------\n"
                     + "java oracle.forms.jdapi.demo.ChangeColor FORM=<name>\n "
                     + "TARGET_TYPE=CANVAS|ITEM\n CANVAS_TYPE=[ALL]|CONTENT|STACKED|TAB|HTOOLBAR|VTOOLBAR\n "
                     + "ITEM_TYPE=[ALL]|TEXT|DISPLAY|CHECKBOX|BUTTON|LIST\n FOREGROUND=<color>\n "
                     + "BACKGROUND=<color>");
  }
  
  public static void main(String[] args)
  {
    ChangeColors changeColors = new ChangeColors(args);
  }
}