package oracle.forms.jdapi.demo;

import oracle.forms.jdapi.*;

/** Forms JAVA API (JDAPI): <b>Sample 1</b> - <em>GetFormName</em><br>
 *  The simplest possible Forms API Demo which opens the Form FMB file
 *  which is supplied as an argument to the program and prints out the
 *  name of the Form
 *
 * @author drmills
 * @author 09-August-2001
 * @version 1.0
 */

public class GetFormName
{

  static String s_sample_name    = "GetFormName";
  static String s_sample_version = "1.0";
  /**
   * Everything in this class is done in the constructor
   * @param <b>formName</b> the file name of the Form to open
   * @return no return value
   * @exception no exceptions thrown
   */
  public GetFormName(String formName)
  {
    //Print header
    System.out.println(s_sample_name + " Version " + s_sample_version);

    try
    {
      // Open the module - this implicitly starts JDAPI
      FormModule form = FormModule.open(formName);

      // Call the getName method on the new Form object
      System.out.println("Form Name is " + form.getName());

      // Close the Form - the shutdown would actually do this for us
      // so there is no real need to do it explicitly
      form.destroy();

      // Clean Up
      Jdapi.shutdown();

    }
    catch (JdapiException jdex)
    {
      System.out.println(jdex.toString());
    }
  }

  /**
   * Simply creates a new instance of the GetFormName class, passing the
   * first string on the command line as the name of the form.
   * @param <b>args</b>Command line strings passed to the Java command
   */
  public static void main(String[] args)
  {
    //No Need to Initialise the API - This is done
    //implicitly by the first JDAPI call
    //We assume just one argument with the name of the
    // Form has been passed.
    try 
    {
      GetFormName getFormName = new GetFormName(args[0]);
    }
    catch (java.lang.ArrayIndexOutOfBoundsException aiobex)
    {
      System.out.println("ERROR: Please supply a form name as an argument to this class");
    }    
  }
}