package oracle.forms.jdapi.demo;

import oracle.forms.jdapi.*;

/** Forms JAVA API (JDAPI): <b>Sample 2</b> - <em>GetModuleName</em><br>
 *  An evolution of the basic GetFormName class, that can open any Forms module
 *  type, not just FMBs.  This demonstrates the use of the JdapiModule superclass<br>
 *  Prints the name of the Forms module (FMB, OLB, PLL or MMB) which is
 *  supplied as an argument to the program.
 *
 * @author drmills
 * @author 09-August-2001
 * @version 1.0
 */
public class GetModuleName
{
  static String s_sample_name    = "GetModuleName";
  static String s_sample_version = "1.0";

  /**
   * Everything in this class is done in the constructor.<br>
   * This class starts to do more advanced operations.  Some of the JDAPI
   * option flags are set:
   * <ul>
   *   <li>setFailSubclassLoad - false - continue even if a reference module cannot be found</li>
   *   <li>setFailLibraryLoad - false - continue even if an attached library cannot be found</li>
   * </ul>
   * The JDAPI is also explicitly shutdown when finished with.
   *
   * @param <b>moduleName</b> the file name of the Forms module to open
   * @return no return value
   * @exception no exceptions thrown
   */
  public GetModuleName(String moduleName)
  {

    //Print header
    System.out.println(s_sample_name + " Version " + s_sample_version);

    // suppress errors from missing subclassed modules & PLLs
    // And don't worry about the compilation state to
    // save time
    Jdapi.setFailSubclassLoad(false);
    Jdapi.setFailLibraryLoad(false);

    try
    {
      //Attempt to open the module
      JdapiModule mod = JdapiModule.openModule(moduleName);

      //Print out the Module name and type
      System.out.println("Module name is " + mod.getName() + ", of type " + mod.getClassName());
    }
    catch (JdapiException jdex)
    {
      System.out.println(jdex.toString());
    }

    //Cleanup
    Jdapi.shutdown();
  }
  /**
   * Simply creates a new instance of the GetModuleName class, passing the
   * first string on the command line as the name of the forms module.
   * @param <b>args</b>Command line strings passed to the Java command
   */
  public static void main(String[] args)
  {
    try 
    {
      GetModuleName GetModuleName = new GetModuleName(args[0]);
    }
    catch (java.lang.ArrayIndexOutOfBoundsException aiobex)
    {
      System.out.println("ERROR: Please supply a module name as an argument to this class");
    }   
  }
}